@@ -19,11 +19,14 @@ from astropy import coordinates, units
 # import spectra
 logger = logging.getLogger(__name__)
 
-SECPERDAY = float('86400.0')
+SECPERDAY = float("86400.0")
 
 # Regular expression for parsing DATE-OBS card's format.
-date_obs_re = re.compile(r"^(?P<year>[0-9]{4})-(?P<month>[0-9]{2})-(?P<day>[0-9]{2})T(?P<hour>[0-9]{2}):"
-                         r"(?P<min>[0-9]{2}):(?P<sec>[0-9]{2}""(?:\.[0-9]+)?)$")
+date_obs_re = re.compile(
+    r"^(?P<year>[0-9]{4})-(?P<month>[0-9]{2})-(?P<day>[0-9]{2})T(?P<hour>[0-9]{2}):"
+    r"(?P<min>[0-9]{2}):(?P<sec>[0-9]{2}"
+    "(?:\.[0-9]+)?)$"
+)
 
 
 def unpack_2bit(data):
@@ -100,13 +103,12 @@ class PsrfitsFile(object):
     def __init__(self, psrfitslist):
         psrfitsfn = psrfitslist[0]
         if not os.path.isfile(psrfitsfn):
-            raise ValueError("ERROR: File does not exist!\n\t(%s)" % \
-                             psrfitsfn)
+            raise ValueError("ERROR: File does not exist!\n\t(%s)" % psrfitsfn)
         self.filename = psrfitsfn
         self.filelist = psrfitslist
         self.fileid = 0
 
-        self.fits = pyfits.open(psrfitsfn, mode='readonly', memmap=True)
+        self.fits = pyfits.open(psrfitsfn, mode="readonly", memmap=True)
         self.specinfo = SpectraInfo(psrfitslist)
         self.header = self.fits[0].header  # Primary HDU
         self.nbits = self.specinfo.bits_per_sample
@@ -116,24 +118,26 @@ class PsrfitsFile(object):
         self.poln_order = self.specinfo.poln_order
         self.nsamp_per_subint = self.specinfo.spectra_per_subint
         self.nsubints = self.specinfo.num_subint[0]
-        self.freqs = self.fits['SUBINT'].data[0]['DAT_FREQ']
+        self.freqs = self.fits["SUBINT"].data[0]["DAT_FREQ"]
         self.frequencies = self.freqs  # Alias
         self.nspec = self.specinfo.N
 
         # Unifying properties with pysigproc
         self.npol = self.npoln
-        self.bw = self.header['OBSBW']
-        self.cfreq = self.header['OBSFREQ']
+        self.bw = self.header["OBSBW"]
+        self.cfreq = self.header["OBSFREQ"]
         self.fch1 = self.cfreq - self.bw / 2.0  # Verify
         self.foff = self.bw / self.nchan
         self.nchans = self.nchan
         self.tstart = self.specinfo.start_MJD[0]
         self.source_name = self.specinfo.source
-        loc = coordinates.SkyCoord(self.header['RA'], self.header['DEC'], unit=(units.hourangle, units.deg))
+        loc = coordinates.SkyCoord(
+            self.header["RA"], self.header["DEC"], unit=(units.hourangle, units.deg)
+        )
         self.ra_deg = loc.ra.value
         self.dec_deg = loc.dec.value
-        self.telescope = self.header['TELESCOP'].strip()
-        self.backend = self.header['BACKEND'].strip()
+        self.telescope = self.header["TELESCOP"].strip()
+        self.backend = self.header["BACKEND"].strip()
 
     def nspectra(self):
         """
@@ -184,8 +188,9 @@ class PsrfitsFile(object):
         """
         return self.nchan
 
-    def read_subint(self, isub, apply_weights=True, apply_scales=True, \
-                    apply_offsets=True, pol=0):
+    def read_subint(
+        self, isub, apply_weights=True, apply_scales=True, apply_offsets=True, pol=0
+    ):
         """
         Read a PSRFITS subint from a open pyfits file object.
         Applys scales, weights, and offsets to the data.
@@ -200,17 +205,21 @@ class PsrfitsFile(object):
             np.ndarray : Subint data with scales, weights, and offsets applied in float32 dtype with shape (nsamps,nchan).
 
         """
-        sdata = self.fits['SUBINT'].data[isub]['DATA']
+        sdata = self.fits["SUBINT"].data[isub]["DATA"]
         shp = sdata.squeeze().shape
 
         if pol > 0:
-            assert self.poln_order == "IQUV", "Polarisation order in the file should be IQUV with pol=1 or pol=2"
+            assert (
+                self.poln_order == "IQUV"
+            ), "Polarisation order in the file should be IQUV with pol=1 or pol=2"
 
         if self.nbits < 8:  # Unpack the bytes data
-            if (shp[0] != self.nsamp_per_subint) and \
-                    (shp[1] != self.nchan * self.nbits / 8):
-                sdata = sdata.reshape(self.nsamp_per_subint,
-                                      int(self.nchan * self.nbits / 8))
+            if (shp[0] != self.nsamp_per_subint) and (
+                shp[1] != self.nchan * self.nbits / 8
+            ):
+                sdata = sdata.reshape(
+                    self.nsamp_per_subint, int(self.nchan * self.nbits / 8)
+                )
             if self.nbits == 4:
                 data = unpack_4bit(sdata)
             elif self.nbits == 2:
@@ -219,18 +228,14 @@ class PsrfitsFile(object):
                 data = np.asarray(sdata)
         else:
             # Handle 4-poln GUPPI/PUPPI data
-            if (len(shp) == 3 and shp[1] == self.npoln and
-                    self.poln_order == "AABBCRCI"):
+            if len(shp) == 3 and shp[1] == self.npoln and self.poln_order == "AABBCRCI":
                 logger.warning("Polarization is AABBCRCI, summing AA and BB")
-                data = np.zeros((self.nsamp_per_subint,
-                                 self.nchan), dtype=np.float32)
+                data = np.zeros((self.nsamp_per_subint, self.nchan), dtype=np.float32)
                 data += sdata[:, 0, :].squeeze()
                 data += sdata[:, 1, :].squeeze()
-            elif (len(shp) == 3 and shp[1] == self.npoln and
-                  self.poln_order == "IQUV"):
+            elif len(shp) == 3 and shp[1] == self.npoln and self.poln_order == "IQUV":
                 logger.warning("Polarization is IQUV")
-                data = np.zeros((self.nsamp_per_subint,
-                                 self.nchan), dtype=np.float32)
+                data = np.zeros((self.nsamp_per_subint, self.nchan), dtype=np.float32)
                 if pol == 0:
                     logger.info("Just using Stokes I.")
                     data += sdata[:, 0, :].squeeze()
@@ -248,14 +253,24 @@ class PsrfitsFile(object):
                     data = data + ((sdata[:, 0, :] - sdata[:, 1, :]) / 2).squeeze()
                 else:
                     raise ValueError(f"pol={pol} value not supported.")
-
+            elif len(shp) == 4 and shp[-1] == 2 and self.poln_order == "IQUV":
+                logger.warning(
+                    "Data is packed as two uint8 arrays. Concatenating them to get uint16."
+                )
+                logger.warning("Polarization is IQUV. Just using Stokes I.")
+                data = np.zeros((self.nsamp_per_subint, self.nchan), dtype=np.float32)
+                data1 = sdata[:, 0, :, 0].astype(np.uint16)
+                data2 = sdata[:, 0, :, 1].astype(np.uint16)
+                data += np.left_shift(data2, 8) + data1
             else:
                 data = np.asarray(sdata)
-        data = data.reshape((self.nsamp_per_subint,
-                             self.nchan)).astype(np.float32)
-        if apply_scales: data *= self.get_scales(isub)[:self.nchan]
-        if apply_offsets: data += self.get_offsets(isub)[:self.nchan]
-        if apply_weights: data *= self.get_weights(isub)[:self.nchan]
+        data = data.reshape((self.nsamp_per_subint, self.nchan)).astype(np.float32)
+        if apply_scales:
+            data *= self.get_scales(isub)[: self.nchan]
+        if apply_offsets:
+            data += self.get_offsets(isub)[: self.nchan]
+        if apply_weights:
+            data *= self.get_weights(isub)[: self.nchan]
         return data
 
     def get_weights(self, isub):
@@ -269,7 +284,7 @@ class PsrfitsFile(object):
             np.ndarray : Subint weights. (There is one value for each channel)
 
         """
-        return self.fits['SUBINT'].data[isub]['DAT_WTS']
+        return self.fits["SUBINT"].data[isub]["DAT_WTS"]
 
     def get_scales(self, isub):
         """
@@ -282,7 +297,7 @@ class PsrfitsFile(object):
             np.ndarray : Subint scales. (There is one value for each channel)
 
         """
-        return self.fits['SUBINT'].data[isub]['DAT_SCL']
+        return self.fits["SUBINT"].data[isub]["DAT_SCL"]
 
     def get_offsets(self, isub):
         """
@@ -295,7 +310,7 @@ class PsrfitsFile(object):
             np.ndarray : Subint offsets. (There is one value for each channel)
 
         """
-        return self.fits['SUBINT'].data[isub]['DAT_OFFS']
+        return self.fits["SUBINT"].data[isub]["DAT_OFFS"]
 
     def get_data(self, nstart, nsamp, pol=0):
         """
@@ -325,8 +340,8 @@ class PsrfitsFile(object):
         else:
             trunc = int(((endsub + 1) * self.nsamp_per_subint) - (nstart + nsamp))
 
-        logger.debug(f'Number of spectra to skip from start: {skip}')
-        logger.debug(f'Number of spectra to truncate from end: {trunc}')
+        logger.debug(f"Number of spectra to skip from start: {skip}")
+        logger.debug(f"Number of spectra to truncate from end: {trunc}")
 
         cumsum_num_subint = np.cumsum(self.specinfo.num_subint)
         startfileid = np.where(startsub < cumsum_num_subint)[0][0]
@@ -334,14 +349,14 @@ class PsrfitsFile(object):
 
         if startfileid != self.fileid:
             self.fileid = startfileid
-            logger.debug(f'Updating fileid to {self.fileid}')
+            logger.debug(f"Updating fileid to {self.fileid}")
 
             self.fits.close()
-            del self.fits['SUBINT']
+            del self.fits["SUBINT"]
             logger.debug("Deleted mmap'ed object")
             self.filename = self.filelist[self.fileid]
             logger.debug(f"File id is {self.fileid}, Reading file: {self.filename}")
-            self.fits = pyfits.open(self.filename, mode='readonly', memmap=True)
+            self.fits = pyfits.open(self.filename, mode="readonly", memmap=True)
 
         # Read data
         data = []
@@ -351,34 +366,40 @@ class PsrfitsFile(object):
             logger.debug(f"file id is {self.fileid}")
 
             if isub > cumsum_num_subint[self.fileid] - 1:
-                logger.debug(f'isub lies in a later file')
+                logger.debug(f"isub lies in a later file")
                 self.fits.close()
-                del self.fits['SUBINT']
+                del self.fits["SUBINT"]
                 logger.debug("Delted mmap'ed object")
                 self.fileid += 1
                 if self.fileid == len(self.filelist):
-                    logger.warning(f"Not enough subints, returning data till last subint")
-                    logger.debug(f'Setting file ID to that of last file')
+                    logger.warning(
+                        f"Not enough subints, returning data till last subint"
+                    )
+                    logger.debug(f"Setting file ID to that of last file")
                     self.fileid -= 1
                     break
                 logger.debug(f"Updating file ID to: {self.fileid}")
                 self.filename = self.filelist[self.fileid]
                 logger.debug(f"Reading file: {self.filename}")
-                self.fits = pyfits.open(self.filename, mode='readonly', memmap=True)
+                self.fits = pyfits.open(self.filename, mode="readonly", memmap=True)
 
             logger.debug(f"Using: {self.fits}")
-            fsub = int((isub - np.concatenate([np.array([0]), cumsum_num_subint]))[self.fileid])
-            logger.debug(f'Reading subint {fsub} in file {self.filename}')
+            fsub = int(
+                (isub - np.concatenate([np.array([0]), cumsum_num_subint]))[self.fileid]
+            )
+            logger.debug(f"Reading subint {fsub} in file {self.filename}")
             try:
                 data.append(self.read_subint(fsub, pol=pol))
             except KeyError:
-                logger.warning(f"Encountered KeyError, maybe mmap'd object was delected")
+                logger.warning(
+                    f"Encountered KeyError, maybe mmap'd object was delected"
+                )
                 logger.debug(f"Trying to open file {self.filename}")
-                self.fits = pyfits.open(self.filename, mode='readonly', memmap=True)
-                logger.debug(f'Reading subint {fsub} in file {self.filename}')
+                self.fits = pyfits.open(self.filename, mode="readonly", memmap=True)
+                logger.debug(f"Reading subint {fsub} in file {self.filename}")
                 data.append(self.read_subint(fsub, pol=pol))
 
-        logging.debug(f'Read all the necessary subints')
+        logging.debug(f"Read all the necessary subints")
         if len(data) > 1:
             data = np.concatenate(data)
         else:
@@ -435,17 +456,17 @@ class SpectraInfo:
                 raise ValueError("File '%s' does not appear to be PSRFITS!" % fn)
 
             # Open the PSRFITS file
-            with pyfits.open(fn, mode='readonly', memmap=True) as hdus:
+            with pyfits.open(fn, mode="readonly", memmap=True) as hdus:
 
                 if ii == 0:
                     self.hdu_names = [hdu.name for hdu in hdus]
 
-                primary = hdus['PRIMARY'].header
+                primary = hdus["PRIMARY"].header
 
-                if 'TELESCOP' not in primary.keys():
+                if "TELESCOP" not in primary.keys():
                     telescope = ""
                 else:
-                    telescope = primary['TELESCOP']
+                    telescope = primary["TELESCOP"]
                     # Quick fix for MockSpec data...
                     if telescope == "ARECIBO 305m":
                         telescope = "Arecibo"
@@ -454,62 +475,69 @@ class SpectraInfo:
                 else:
                     if telescope != self.telescope[0]:
                         logger.warning(
-                            f"'TELESCOP' values don't match for files 0 ({self.telescope[0]}) and {ii}({telescope})!")
+                            f"'TELESCOP' values don't match for files 0 ({self.telescope[0]}) and {ii}({telescope})!"
+                        )
 
-                self.observer = primary['OBSERVER']
-                self.source = primary['SRC_NAME']
-                self.frontend = primary['FRONTEND']
-                self.backend = primary['BACKEND']
-                self.project_id = primary['PROJID']
-                self.date_obs = primary['DATE-OBS']
-                self.poln_type = primary['FD_POLN']
-                self.ra_str = primary['RA']
-                self.dec_str = primary['DEC']
-                self.fctr = primary['OBSFREQ']
-                self.orig_num_chan = primary['OBSNCHAN']
-                self.orig_df = primary['OBSBW']
-                self.beam_FWHM = primary['BMIN']
+                self.observer = primary["OBSERVER"]
+                self.source = primary["SRC_NAME"]
+                self.frontend = primary["FRONTEND"]
+                self.backend = primary["BACKEND"]
+                self.project_id = primary["PROJID"]
+                self.date_obs = primary["DATE-OBS"]
+                self.poln_type = primary["FD_POLN"]
+                self.ra_str = primary["RA"]
+                self.dec_str = primary["DEC"]
+                self.fctr = primary["OBSFREQ"]
+                self.orig_num_chan = primary["OBSNCHAN"]
+                self.orig_df = primary["OBSBW"]
+                self.beam_FWHM = primary["BMIN"]
 
                 # CHAN_DM card is not in earlier versions of PSRFITS
-                if 'CHAN_DM' not in primary.keys():
+                if "CHAN_DM" not in primary.keys():
                     self.chan_dm = 0.0
                 else:
-                    self.chan_dm = primary['CHAN_DM']
+                    self.chan_dm = primary["CHAN_DM"]
 
-                self.start_MJD[ii] = primary['STT_IMJD'] + (primary['STT_SMJD'] + \
-                                                            primary['STT_OFFS']) / SECPERDAY
+                self.start_MJD[ii] = (
+                    primary["STT_IMJD"]
+                    + (primary["STT_SMJD"] + primary["STT_OFFS"]) / SECPERDAY
+                )
 
                 # Are we tracking
-                track = (primary['TRK_MODE'] == "TRACK")
+                track = primary["TRK_MODE"] == "TRACK"
                 if ii == 0:
                     self.tracking = track
                 else:
                     if track != self.tracking:
-                        logger.warning("'TRK_MODE' values don't match for files 0 and %d" % ii)
+                        logger.warning(
+                            "'TRK_MODE' values don't match for files 0 and %d" % ii
+                        )
 
                 # Now switch to the subint HDU header
-                subint = hdus['SUBINT'].header
+                subint = hdus["SUBINT"].header
 
-                self.dt = subint['TBIN']
-                self.num_channels = subint['NCHAN']
-                self.num_polns = subint['NPOL']
+                self.dt = subint["TBIN"]
+                self.num_channels = subint["NCHAN"]
+                self.num_polns = subint["NPOL"]
 
                 # PRESTO's 'psrfits.c' has some settings based on environ variables
                 envval = os.getenv("PSRFITS_POLN")
                 if envval is not None:
                     ival = int(envval)
-                    if ((ival > -1) and (ival < self.num_polns)):
-                        logger.info(f"Using polarisation {ival} (from 0-{self.num_polns - 1}) from PSRFITS_POLN.")
+                    if (ival > -1) and (ival < self.num_polns):
+                        logger.info(
+                            f"Using polarisation {ival} (from 0-{self.num_polns - 1}) from PSRFITS_POLN."
+                        )
                         self.default_poln = ival
                         self.user_poln = 1
 
-                self.poln_order = subint['POL_TYPE']
-                if subint['NCHNOFFS'] > 0:
+                self.poln_order = subint["POL_TYPE"]
+                if subint["NCHNOFFS"] > 0:
                     logger.warning("first freq channel is not 0 in file %d" % ii)
-                self.spectra_per_subint = subint['NSBLK']
-                self.bits_per_sample = subint['NBITS']
-                self.num_subint[ii] = subint['NAXIS2']
-                self.start_subint[ii] = subint['NSUBOFFS']
+                self.spectra_per_subint = subint["NSBLK"]
+                self.bits_per_sample = subint["NBITS"]
+                self.num_subint[ii] = subint["NAXIS2"]
+                self.start_subint[ii] = subint["NSUBOFFS"]
                 self.time_per_subint = self.dt * self.spectra_per_subint
 
                 # This is the MJD offset based on the starting subint number
@@ -522,56 +550,62 @@ class SpectraInfo:
                 if MJDf < 0.0:
                     raise ValueError("File %d seems to be from before file 0!" % ii)
 
-                self.start_spec[ii] = (MJDf * SECPERDAY / self.dt + 0.5)
+                self.start_spec[ii] = MJDf * SECPERDAY / self.dt + 0.5
 
                 # Now pull stuff from the columns
-                subint_hdu = hdus['SUBINT']
+                subint_hdu = hdus["SUBINT"]
                 first_subint = subint_hdu.data[0]
                 # Identify the OFFS_SUB column number
-                if 'OFFS_SUB' not in subint_hdu.columns.names:
+                if "OFFS_SUB" not in subint_hdu.columns.names:
                     logger.warning("Can't find the 'OFFS_SUB' column!")
                 else:
-                    colnum = subint_hdu.columns.names.index('OFFS_SUB')
+                    colnum = subint_hdu.columns.names.index("OFFS_SUB")
                     if ii == 0:
                         self.offs_sub_col = colnum
                     elif self.offs_sub_col != colnum:
-                        logger.warning("'OFFS_SUB' column changes between files 0 and %d!" % ii)
+                        logger.warning(
+                            "'OFFS_SUB' column changes between files 0 and %d!" % ii
+                        )
 
                 # Identify the data column and the data type
-                if 'DATA' not in subint_hdu.columns.names:
+                if "DATA" not in subint_hdu.columns.names:
                     logger.warning("Can't find the 'DATA' column!")
                 else:
-                    colnum = subint_hdu.columns.names.index('DATA')
+                    colnum = subint_hdu.columns.names.index("DATA")
                     if ii == 0:
                         self.data_col = colnum
-                        self.FITS_typecode = subint_hdu.columns[self.data_col].format[-1]
+                        self.FITS_typecode = subint_hdu.columns[self.data_col].format[
+                            -1
+                        ]
                     elif self.data_col != colnum:
-                        logger.warning("'DATA' column changes between files 0 and %d!" % ii)
+                        logger.warning(
+                            "'DATA' column changes between files 0 and %d!" % ii
+                        )
 
                 # Telescope azimuth
-                if 'TEL_AZ' not in subint_hdu.columns.names:
+                if "TEL_AZ" not in subint_hdu.columns.names:
                     self.azimuth = 0.0
                 else:
-                    colnum = subint_hdu.columns.names.index('TEL_AZ')
+                    colnum = subint_hdu.columns.names.index("TEL_AZ")
                     if ii == 0:
                         self.tel_az_col = colnum
-                        self.azimuth = first_subint['TEL_AZ']
+                        self.azimuth = first_subint["TEL_AZ"]
 
                 # Telescope zenith angle
-                if 'TEL_ZEN' not in subint_hdu.columns.names:
+                if "TEL_ZEN" not in subint_hdu.columns.names:
                     self.zenith_ang = 0.0
                 else:
-                    colnum = subint_hdu.columns.names.index('TEL_ZEN')
+                    colnum = subint_hdu.columns.names.index("TEL_ZEN")
                     if ii == 0:
                         self.tel_zen_col = colnum
-                        self.zenith_ang = first_subint['TEL_ZEN']
+                        self.zenith_ang = first_subint["TEL_ZEN"]
 
                 # Observing frequencies
-                if 'DAT_FREQ' not in subint_hdu.columns.names:
+                if "DAT_FREQ" not in subint_hdu.columns.names:
                     logger.warning("Can't find the channel freq column, 'DAT_FREQ'!")
                 else:
-                    colnum = subint_hdu.columns.names.index('DAT_FREQ')
-                    freqs = first_subint['DAT_FREQ']
+                    colnum = subint_hdu.columns.names.index("DAT_FREQ")
+                    freqs = first_subint["DAT_FREQ"]
                     if ii == 0:
                         self.freqs_col = colnum
                         self.df = freqs[1] - freqs[0]
@@ -584,48 +618,60 @@ class SpectraInfo:
                     else:
                         ftmp = np.abs(self.df - (freqs[1] - freqs[0]))
                         if ftmp > 1e-7:
-                            logger.warning("Channel spacing between files 0 and %d!" % ii)
+                            logger.warning(
+                                "Channel spacing between files 0 and %d!" % ii
+                            )
                         ftmp = np.abs(self.lo_freq - freqs[0])
                         if ftmp > 1e-7:
-                            logger.warning("Low channel changes between files 0 and %d!" % ii)
+                            logger.warning(
+                                "Low channel changes between files 0 and %d!" % ii
+                            )
                         ftmp = np.abs(self.hi_freq - freqs[-1])
                         if ftmp > 1e-7:
-                            logger.warning("High channel changes between files 0 and %d!" % ii)
+                            logger.warning(
+                                "High channel changes between files 0 and %d!" % ii
+                            )
 
                 # Data weights
-                if 'DAT_WTS' not in subint_hdu.columns.names:
+                if "DAT_WTS" not in subint_hdu.columns.names:
                     logger.warning("Can't find the channel weights column, 'DAT_WTS'!")
                 else:
-                    colnum = subint_hdu.columns.names.index('DAT_WTS')
+                    colnum = subint_hdu.columns.names.index("DAT_WTS")
                     if ii == 0:
                         self.dat_wts_col = colnum
                     elif self.dat_wts_col != colnum:
-                        logger.warning("'DAT_WTS column changes between files 0 and %d!" % ii)
-                    if np.any(first_subint['DAT_WTS'] != 1.0):
+                        logger.warning(
+                            "'DAT_WTS column changes between files 0 and %d!" % ii
+                        )
+                    if np.any(first_subint["DAT_WTS"] != 1.0):
                         self.need_weight = True
 
                 # Data offsets
-                if 'DAT_OFFS' not in subint_hdu.columns.names:
+                if "DAT_OFFS" not in subint_hdu.columns.names:
                     logger.warning("Can't find the channel offsets column, 'DAT_OFFS'!")
                 else:
-                    colnum = subint_hdu.columns.names.index('DAT_OFFS')
+                    colnum = subint_hdu.columns.names.index("DAT_OFFS")
                     if ii == 0:
                         self.dat_offs_col = colnum
                     elif self.dat_offs_col != colnum:
-                        logger.warning("'DAT_OFFS column changes between files 0 and %d!" % ii)
-                    if np.any(first_subint['DAT_OFFS'] != 0.0):
+                        logger.warning(
+                            "'DAT_OFFS column changes between files 0 and %d!" % ii
+                        )
+                    if np.any(first_subint["DAT_OFFS"] != 0.0):
                         self.need_offset = True
 
                 # Data scalings
-                if 'DAT_SCL' not in subint_hdu.columns.names:
+                if "DAT_SCL" not in subint_hdu.columns.names:
                     logger.warning("Can't find the channel scalings column, 'DAT_SCL'!")
                 else:
-                    colnum = subint_hdu.columns.names.index('DAT_SCL')
+                    colnum = subint_hdu.columns.names.index("DAT_SCL")
                     if ii == 0:
                         self.dat_scl_col = colnum
                     elif self.dat_scl_col != colnum:
-                        logger.warning("'DAT_SCL' column changes between files 0 and %d!" % ii)
-                    if np.any(first_subint['DAT_SCL'] != 1.0):
+                        logger.warning(
+                            "'DAT_SCL' column changes between files 0 and %d!" % ii
+                        )
+                    if np.any(first_subint["DAT_SCL"] != 1.0):
                         self.need_scale = True
 
                 # Comute the samples per file and the amount of padding
@@ -639,7 +685,7 @@ class SpectraInfo:
                 self.N += self.num_spec[ii]
 
         # Finished looping through PSRFITS files. Finalise a few things.
-        # Convert the position strings into degrees        
+        # Convert the position strings into degrees
         self.ra2000 = coordinates.Angle(self.ra_str, unit=units.hourangle).deg
         self.dec2000 = coordinates.Angle(self.dec_str, unit=units.deg).deg
 
@@ -658,7 +704,9 @@ class SpectraInfo:
         if self.bits_per_sample < 8:
             self.bytes_per_spectra = self.samples_per_spectra
         else:
-            self.bytes_per_spectra = (self.bits_per_sample * self.samples_per_spectra) / 8
+            self.bytes_per_spectra = (
+                self.bits_per_sample * self.samples_per_spectra
+            ) / 8
         self.samples_per_subint = self.samples_per_spectra * self.spectra_per_subint
         self.bytes_per_subint = self.bytes_per_spectra * self.spectra_per_subint
 
@@ -681,7 +729,7 @@ class SpectraInfo:
         """
         result = []  # list of strings. Will be concatenated with newlines (\n).
         result.append("From the PSRFITS file '%s':" % self.filenames[0])
-        result.append("                       HDUs = %s" % ', '.join(self.hdu_names))
+        result.append("                       HDUs = %s" % ", ".join(self.hdu_names))
         result.append("                  Telescope = %s" % self.telescope)
         result.append("                   Observer = %s" % self.observer)
         result.append("                Source Name = %s" % self.source)
@@ -725,7 +773,9 @@ class SpectraInfo:
         result.append("            Starting subint = %d" % self.start_subint[0])
         result.append("           Subints per file = %d" % self.num_subint[0])
         result.append("           Spectra per file = %d" % self.num_spec[0])
-        result.append("        Time per file (sec) = %-.12g" % (self.num_spec[0] * self.dt))
+        result.append(
+            "        Time per file (sec) = %-.12g" % (self.num_spec[0] * self.dt)
+        )
         result.append("              FITS typecode = %s" % self.FITS_typecode)
         result.append("                DATA column = %d" % self.data_col)
         result.append("            bits per sample = %d" % self.bits_per_sample)
@@ -744,7 +794,7 @@ class SpectraInfo:
         result.append("              Need weights? = %s" % self.need_weight)
         result.append("        Need band inverted? = %s" % self.need_flipband)
 
-        return '\n'.join(result)
+        return "\n".join(result)
 
     def __getitem__(self, key):
         return getattr(self, key)
@@ -760,10 +810,15 @@ def DATEOBS_to_MJD(dateobs):
     """
     # Parse string using regular expression defined at top of file
     m = date_obs_re.match(dateobs)
-    mjd_fracday = (float(m.group("hour")) + (float(m.group("min")) + \
-                                             (float(m.group("sec")) / 60.0)) / 60.0) / 24.0
-    mjd_day = aptime.Time("%d-%d-%d" % (float(m.group("year")), \
-                                        float(m.group("month")), float(m.group("day"))), format="iso").mjd
+    mjd_fracday = (
+        float(m.group("hour"))
+        + (float(m.group("min")) + (float(m.group("sec")) / 60.0)) / 60.0
+    ) / 24.0
+    mjd_day = aptime.Time(
+        "%d-%d-%d"
+        % (float(m.group("year")), float(m.group("month")), float(m.group("day"))),
+        format="iso",
+    ).mjd
     return mjd_day, mjd_fracday
 
 
@@ -773,12 +828,13 @@ def is_PSRFITS(filename):
         bool: True if filename appears to be PSRFITS format. Return False otherwise.
 
     """
-    with pyfits.open(filename, mode='readonly', memmap=True) as hdus:
-        primary = hdus['PRIMARY'].header
+    with pyfits.open(filename, mode="readonly", memmap=True) as hdus:
+        primary = hdus["PRIMARY"].header
 
         try:
-            isPSRFITS = ((primary['FITSTYPE'] == "PSRFITS") and \
-                         (primary['OBS_MODE'] == "SEARCH"))
+            isPSRFITS = (primary["FITSTYPE"] == "PSRFITS") and (
+                primary["OBS_MODE"] == "SEARCH"
+            )
         except KeyError:
             isPSRFITS = False
 
